@@ -1,14 +1,17 @@
 class Crypter:
 
 	def encrypt_caesar_cipher(text, password):
-		if type(password) == str:
+		if type(password) is str:
 			psw = 0
 			for x in range(len(password)):
 				psw += ord(password[-(x + 1)]) * (x + 1)
 
-		else:
+		elif type(password) is int:
 			psw = password
 
+		else:
+			return None
+
 		output_text = ''
 
 		for x in text:
@@ -17,17 +20,20 @@ class Crypter:
 		return output_text
 
 	def decrypt_caesar_cipher(text, password):
-		if type(password) == str:
+		if type(password) is str:
 			psw = 0
 			for x in range(len(password)):
 				psw += ord(password[-(x + 1)]) * (x + 1)
 
-		else:
+		elif type(password) is int:
 			psw = password
 
+		else:
+			return None
+
 		output_text = ''
 
 		for x in text:
 			output_text += chr(ord(x) - psw)
 
-		return output_text
\ No newline at end of file
+		return output_text
